==> nextcloud-20.0.13.tgz: nextcloud/apps/oauth2/l10n/fr.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Votre client n'est pas autoriser à se connecter. Veuillez informer l'administrateur de votre client.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Votre adresse de redirection doit être une URL complète, par exemple: https://example.com/chemin",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Autoriser l'authentification compatible OAuth2 depuis d'autres applications web.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "L'application OAuth2 permet aux administrateurs de configurer le processus d'authentification intégrée afin d'autoriser l'authentification compatible OAuth2 depuis d'autres applications web.",
    "OAuth 2.0 clients" : "Clients OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 permet à des services externes de demander l'accès à {instanceName}.",
    "Add client" : "Ajouter un client",
    "Name" : "Nom",
    "Redirection URI" : "URI de redirection",
    "Add" : "Ajouter",
    "Client Identifier" : "Identifiant du client",
    "Secret" : "Secret",
    "Show client secret" : "Afficher client secret",
    "Delete" : "Supprimer"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-24.0.11p0.tgz: nextcloud/apps/oauth2/l10n/fr.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Votre client n'est pas autoriser à se connecter. Veuillez informer l'administrateur de votre client.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Votre adresse de redirection doit être une URL complète, par exemple: https://example.com/chemin",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Autoriser l'authentification compatible OAuth2 depuis d'autres applications web.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "L'application OAuth2 permet aux administrateurs de configurer le processus d'authentification intégrée afin d'autoriser l'authentification compatible OAuth2 depuis d'autres applications web.",
    "OAuth 2.0 clients" : "Clients OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 permet à des services externes de demander l'accès à {instanceName}.",
    "Add client" : "Ajouter un client",
    "Name" : "Nom",
    "Redirection URI" : "URI de redirection",
    "Add" : "Ajouter",
    "Client Identifier" : "Identifiant du client",
    "Secret" : "Secret",
    "Show client secret" : "Afficher client secret",
    "Delete" : "Supprimer"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
